@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'ឈីឆេន (រុស្ស៊ី)',
         'cs' => 'ឆែក',
         'cs_CZ' => 'ឆែក (ឆែក)',
+        'cv' => 'ឈូវ៉ាស',
+        'cv_RU' => 'ឈូវ៉ាស (រុស្ស៊ី)',
         'cy' => 'វេល',
         'cy_GB' => 'វេល (ចក្រភព​អង់គ្លេស)',
         'da' => 'ដាណឺម៉ាក',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'អង់គ្លេស (ម៉ុងស៊ែរ៉ា)',
         'en_MT' => 'អង់គ្លេស (ម៉ាល់ត៍)',
         'en_MU' => 'អង់គ្លេស (ម៉ូរីស)',
+        'en_MV' => 'អង់គ្លេស (ម៉ាល់ឌីវ)',
         'en_MW' => 'អង់គ្លេស (ម៉ាឡាវី)',
         'en_MY' => 'អង់គ្លេស (ម៉ាឡេស៊ី)',
         'en_NA' => 'អង់គ្លេស (ណាមីប៊ី)',
@@ -238,6 +241,19 @@ return [
         'fa_AF' => 'ភឺសៀន (អាហ្វហ្កានីស្ថាន)',
         'fa_IR' => 'ភឺសៀន (អ៊ីរ៉ង់)',
         'ff' => 'ហ្វ៊ូឡា',
+        'ff_Adlm' => 'ហ្វ៊ូឡា (អាតឡាម)',
+        'ff_Adlm_BF' => 'ហ្វ៊ូឡា (អាតឡាម, បួគីណាហ្វាសូ)',
+        'ff_Adlm_CM' => 'ហ្វ៊ូឡា (អាតឡាម, កាមេរូន)',
+        'ff_Adlm_GH' => 'ហ្វ៊ូឡា (អាតឡាម, ហ្គាណា)',
+        'ff_Adlm_GM' => 'ហ្វ៊ូឡា (អាតឡាម, ហ្គំប៊ី)',
+        'ff_Adlm_GN' => 'ហ្វ៊ូឡា (អាតឡាម, ហ្គីណេ)',
+        'ff_Adlm_GW' => 'ហ្វ៊ូឡា (អាតឡាម, ហ្គីណេប៊ីស្សូ)',
+        'ff_Adlm_LR' => 'ហ្វ៊ូឡា (អាតឡាម, លីបេរីយ៉ា)',
+        'ff_Adlm_MR' => 'ហ្វ៊ូឡា (អាតឡាម, ម៉ូរីតានី)',
+        'ff_Adlm_NE' => 'ហ្វ៊ូឡា (អាតឡាម, នីហ្សេ)',
+        'ff_Adlm_NG' => 'ហ្វ៊ូឡា (អាតឡាម, នីហ្សេរីយ៉ា)',
+        'ff_Adlm_SL' => 'ហ្វ៊ូឡា (អាតឡាម, សៀរ៉ាឡេអូន)',
+        'ff_Adlm_SN' => 'ហ្វ៊ូឡា (អាតឡាម, សេណេហ្គាល់)',
         'ff_CM' => 'ហ្វ៊ូឡា (កាមេរូន)',
         'ff_GN' => 'ហ្វ៊ូឡា (ហ្គីណេ)',
         'ff_Latn' => 'ហ្វ៊ូឡា (ឡាតាំង)',
@@ -328,6 +344,8 @@ return [
         'he_IL' => 'ហេប្រឺ (អ៊ីស្រាអែល)',
         'hi' => 'ហិណ្ឌី',
         'hi_IN' => 'ហិណ្ឌី (ឥណ្ឌា)',
+        'hi_Latn' => 'ហិណ្ឌី (ឡាតាំង)',
+        'hi_Latn_IN' => 'ហិណ្ឌី (ឡាតាំង, ឥណ្ឌា)',
         'hr' => 'ក្រូអាត',
         'hr_BA' => 'ក្រូអាត (បូស្ន៊ី និងហឺហ្ស៊ីហ្គូវីណា)',
         'hr_HR' => 'ក្រូអាត (ក្រូអាស៊ី)',
@@ -372,6 +390,8 @@ return [
         'ks' => 'កាស្មៀរ',
         'ks_Arab' => 'កាស្មៀរ (អារ៉ាប់)',
         'ks_Arab_IN' => 'កាស្មៀរ (អារ៉ាប់, ឥណ្ឌា)',
+        'ks_Deva' => 'កាស្មៀរ (ដាវ៉ាន់ណាការិ)',
+        'ks_Deva_IN' => 'កាស្មៀរ (ដាវ៉ាន់ណាការិ, ឥណ្ឌា)',
         'ks_IN' => 'កាស្មៀរ (ឥណ្ឌា)',
         'ku' => 'ឃឺដ',
         'ku_TR' => 'ឃឺដ (តួកគី)',
@@ -499,6 +519,7 @@ return [
         'sd_Arab_PK' => 'ស៊ីនឌី (អារ៉ាប់, ប៉ាគីស្ថាន)',
         'sd_Deva' => 'ស៊ីនឌី (ដាវ៉ាន់ណាការិ)',
         'sd_Deva_IN' => 'ស៊ីនឌី (ដាវ៉ាន់ណាការិ, ឥណ្ឌា)',
+        'sd_IN' => 'ស៊ីនឌី (ឥណ្ឌា)',
         'sd_PK' => 'ស៊ីនឌី (ប៉ាគីស្ថាន)',
         'se' => 'សាមីខាងជើង',
         'se_FI' => 'សាមីខាងជើង (ហ្វាំងឡង់)',
